@@ -42,7 +42,11 @@ SlideshowScreenSaver::~SlideshowScreenSaver()
 {
 }
 
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
 bool SlideshowScreenSaver::nativeEventFilter(const QByteArray &eventType, void *message, long *result)
+#else
+bool SlideshowScreenSaver::nativeEventFilter(const QByteArray &eventType, void *message, qintptr *result)
+#endif
 {
     Q_UNUSED(result);
     if (eventType == "xcb_generic_event_t") {
@@ -92,7 +96,21 @@ void SlideshowScreenSaver::onUpdateImage()
         loadSlideshowImages();
     }
 
-    m_pixmap.reset(new QPixmap(m_playOrder.value(m_currentIndex)));
+    QPixmap pix(m_playOrder.value(m_currentIndex));
+    if (pix.isNull()) {
+        QImageReader reader(m_playOrder.value(m_currentIndex));
+        reader.setDecideFormatFromContent(true);
+        pix = QPixmap::fromImage(reader.read());
+    }
+
+    m_pixmap.reset(new QPixmap(pix));
+
+    if (m_pixmap && !m_pixmap->isNull()) {
+        m_invaildPath.clear();
+    } else {
+        m_invaildPath = m_playOrder.value(m_currentIndex);
+        qWarning() << "There is an issue with the format of the image" << m_invaildPath;
+    }
     scaledPixmap();
     update();
     return;
@@ -133,17 +151,21 @@ QSize SlideshowScreenSaver::mapFromHandle(const QSize &handleSize)
 void SlideshowScreenSaver::showDefaultBlack(QPaintEvent *event)
 {
     qreal scale = devicePixelRatioF();
-    QPixmap pip(this->geometry().size());
-    pip.fill(Qt::black);
-
-    QPainter pa(&pip);
-    pa.setPen(Qt::white);
-    pa.drawText(pip.rect(), Qt::AlignCenter,
-                tr("Please select a valid image path in the Custom Screensaver \"Screensaver Setting\"."));
-
-    const auto &pix = pip.scaled(mapFromHandle(this->geometry().size()), Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
     QPainter p(this);
-    p.drawPixmap(event->rect().topLeft(), pix, QRectF(QPointF(event->rect().topLeft()) * scale, QSizeF(event->rect().size()) * scale));
+    p.fillRect(this->rect(), Qt::black);
+
+    QRect logicalRect = this->rect();
+    QRect physicalRect(logicalRect.x() / scale,
+                       logicalRect.y() / scale,
+                       logicalRect.width() / scale,
+                       logicalRect.height() / scale);
+
+    QFont font = p.font();
+    font.setPointSizeF(font.pointSizeF() * scale); 
+    p.setFont(font);
+    p.setPen(Qt::white);
+    p.drawText(physicalRect, Qt::AlignCenter,
+                tr("Please select a valid image path in the Custom Screensaver \"Screensaver Setting\".") + m_invaildPath);
 }
 
 void SlideshowScreenSaver::randomImageIndex()
@@ -208,7 +230,15 @@ void SlideshowScreenSaver::initPixMap()
             reader.setDecideFormatFromContent(true);
             pix = QPixmap::fromImage(reader.read());
         }
+
         m_pixmap.reset(new QPixmap(pix));
+
+        if (m_pixmap && !m_pixmap->isNull()) {
+            m_invaildPath.clear();
+        } else {
+            m_invaildPath = m_playOrder.first();
+            qWarning() << "There is an issue with the format of the image" << m_invaildPath;
+        }
         scaledPixmap();
         m_currentIndex = 1;
         m_lastImage = m_playOrder.last();
